@@ -36,7 +36,7 @@ Kwappen::Kwappen()
   sekunden = 0;  // seconds
   found = 0;     // search flag
   swap = 0;      // computer stone swapflag
-  status = 0;    // working level
+  status = -1;   // working level
   reversecolumn = 0;  // reverse column no.
 
   loadOptions(); // load options.txt
@@ -141,10 +141,9 @@ void Kwappen::start_turm()
 
 void Kwappen::draw_turmset()                 // move selected stone
 {
-  char i, j, farbe;
+  char i = 0, j = 0, farbe;
   farbe = turm[stein1old][stein2old];
   turm[stein1old][stein2old] = -1;
-  j = 0;
   for (i=0; i<=11; i++)                      // shrink column
   {
     if (turm[i][stein2old] != -1)
@@ -162,7 +161,6 @@ void Kwappen::draw_turmset()                 // move selected stone
 void Kwappen::set_computer()                 // add computer stone on column top
 {
   char i;
-  spalte1 = random_column();                 // random column
   i = 0;
   while (turm[i][spalte1] > 0) i++;
   turm[i][spalte1] = stein1;
@@ -333,7 +331,7 @@ void Kwappen::ende_check()                       // end checking
   if (win_or_lose == 0)
   {
     stein1 = random_color();
-    status = 0;
+    status = -1;
   }
   repaint();
 }
@@ -375,8 +373,9 @@ void Kwappen::setTextBox(QPainter *p)   // set graphic text (rules)
 void Kwappen::paintEvent(QPaintEvent*)              // paint event
 {
   QPainter p;
-  char reihe, spalte;
-  int pos;
+  char reihe, spalte, pos;
+  QPointArray arrow(4);
+
   static QColor beige (250,245,137);
   p.begin(&buffer);
   if (start == 0)                                   // init graphics
@@ -399,13 +398,13 @@ void Kwappen::paintEvent(QPaintEvent*)              // paint event
   {
     for(reihe = 0; reihe <= 11; reihe++)
     {
-      if (turm[reihe][spalte] > 0)                  // draw stone
+      if (turm[reihe][spalte] > 0)                  // draw stones
       {
         p.drawImage(20+spalte*110, 580-reihe*59, picture, (turm[reihe][spalte] - 1)*79, 0, 79, 59);
       }
-      else                                          // clean column rest
+      else                                          // clean column
       {
-        p.drawImage(20+spalte*110, 20, background, 20+spalte*110, 20, 79, (11-reihe)*59-30);
+        p.drawImage(20+spalte*110, 47, background, 20+spalte*110, 47, 79, (11-reihe)*59-57);
         break;
       }
     }
@@ -413,13 +412,24 @@ void Kwappen::paintEvent(QPaintEvent*)              // paint event
   p.drawImage(500, 80, picture, (stein1-1)*79, 129, 79, 59);  // draw computer stone
   p.setFont(QFont("courier", 24, QFont::Bold));
   p.setPen(Qt::darkBlue);
-  sprintf(zeitstr,"TIME:%5u",sekunden);
+  sprintf(zeitstr,"TIME:%5u",sekunden);                       // show time
   eatblank();
   p.drawText(458,205,180,30, Qt::AlignLeft, zeitstr);
   p.setPen(Qt::black);
   p.drawLine(450,200,630,200);
   p.drawLine(450,239,629,239);
-  switch(status)                                           // select own stone
+  if (status == -1)                                  // start new move
+  {
+    spalte1 = random_column();                       // random column for computer
+    p.drawImage(0, 20, background, 0, 20, 440, 27);
+    arrow.setPoint(0,40+spalte1*110,26);             // draw arrow
+    arrow.setPoint(1,60+spalte1*110,46);
+    arrow.setPoint(2,80+spalte1*110,26);
+    p.drawPolygon(arrow,false,0,3);
+    status = 0;
+  }
+
+  switch(status)                                           // status = game mode
   {
     case 0: p.setPen(Qt::red);
             p.setFont(QFont("courier", 12, QFont::Bold));
@@ -471,13 +481,13 @@ void Kwappen::paintEvent(QPaintEvent*)              // paint event
     case 9: status = 11;                           // you win
             break;
    case 10: timer->stop();
-            status = 0;
+            status = -1;
             QMessageBox::information(0,"Kwappen","The game is over\nYou lose, sorry !");
             start_turm();
             break;
    case 11: timer->stop();                 // stop timer
             sekunden--;
-            status = 0;
+            status = -1;
             pos = highS->testHighscore();  // check highscore entry
             if (pos != -1)
             {
@@ -558,6 +568,7 @@ void Kwappen::keyPressEvent(QKeyEvent* e)
 void Kwappen::newGame()                               // start new game
 {
   start_turm();
+  status = -1;
 }
 
 void Kwappen::autoShrink()                            // set autoshrink delay
@@ -651,7 +662,7 @@ void Kwappen::showHighscore()              // show highscore
 void Kwappen::clearHighscore()             // clear highscore
 {
   FILE* stream;
-  int i;
+  char i;
   QMessageBox *mb = NULL;
   mb = new QMessageBox(i18n("Clear highscore table ?"),
               i18n("Are you sure ?"),
@@ -675,7 +686,7 @@ void Kwappen::clearHighscore()             // clear highscore
 void Highscore::loadHighscore()              // load highscore
 {
   FILE* stream;
-  int i;
+  char i;
   char tempstr[60];
   stream = fopen(home_path+"kwappen/kwappen_highscore.txt", "rt");
   if (! stream)
@@ -703,7 +714,7 @@ void Highscore::loadHighscore()              // load highscore
 void Highscore::paintEvent(QPaintEvent*)      // highscore paint event
 {
   QPainter p;
-  int i;
+  char i;
   char tempstr[60];
   char tempstr1[60];
   FILE* stream;
@@ -742,7 +753,7 @@ void Highscore::closeHighscore()  // hide highscore dialog
    highS->hide();
 }
 
-int Highscore::testHighscore()    // test new highscore entry
+char Highscore::testHighscore()    // test new highscore entry
 {
   int zeit;
   char i;
@@ -759,9 +770,9 @@ int Highscore::testHighscore()    // test new highscore entry
   return -1;
 }
 
-void HighscoreEdit::writeHighscore(int pos)  // write highscore file
+void HighscoreEdit::writeHighscore(char pos)  // write highscore file
 {
-  int i;
+  char i;
   int zeit;
   FILE* stream;
   char tempstr[50];
@@ -795,6 +806,12 @@ void HighscoreEdit::writeHighscore(int pos)  // write highscore file
     }
   }
   fclose(stream);
+  stream = fopen(home_path+"kwappen/kwappen_highscore_name.txt", "wt");  // new highscore table
+  if (stream)
+  {
+    fputs(playerName, stream);
+    fclose(stream);
+  }
 }
 
 Highscore::Highscore(QWidget* parent, const char* name, WFlags f) : QDialog(parent, name, TRUE, f)
@@ -843,6 +860,7 @@ void HighscoreEdit::getHighscore()   // input name highscore of player
 
 HighscoreEdit::HighscoreEdit(QWidget* parent, const char* name, WFlags f) : QDialog(parent, name, TRUE, f)
 {
+  FILE* stream;
   setGeometry(200, 250, 270, 300);
   setMinimumSize(270, 200);           // highscore dialog constructor
   setMaximumSize(270, 200);
@@ -853,7 +871,21 @@ HighscoreEdit::HighscoreEdit(QWidget* parent, const char* name, WFlags f) : QDia
   highscoreentry = new QLineEdit(this);
   highscoreentry->setGeometry(10,120,250,30);
   highscoreentry->setFont(QFont("courier", 14, QFont::Normal));
-  strcpy(playerName,"Noname");
+  stream = fopen(home_path+"kwappen/kwappen_highscore_name.txt", "rt");
+  if (! stream)
+  { stream = fopen(home_path+"kwappen/kwappen_highscore_name.txt", "wt");  // new highscore table
+    if (stream)
+    {
+      fputs("Noname", stream);
+      strcpy(playerName,"Noname");
+      fclose(stream);
+    }
+  }
+  else
+  {
+     fgets(playerName, 20, stream);
+     fclose(stream);
+  }
   connect(highButton, SIGNAL(clicked()),SLOT(getHighscore()));
   connect(highscoreentry, SIGNAL(returnPressed()),SLOT(getHighscore()));
 }
