@@ -44,6 +44,7 @@
 #include <qpixmap.h>
 #include <qobject.h>
 #include <qpainter.h>
+#include <qpoint.h>
 #include <qpushbutton.h>
 #include <qbttngrp.h>
 #include <qstring.h>
@@ -156,7 +157,7 @@ class Highscore : public QDialog
 
   void lookHighscore();
   void loadHighscore();
-  int testHighscore();
+  char testHighscore();
 
   Highscore(QWidget* parent, const char* name = 0, WFlags f = 0);
   ~Highscore(){} };
@@ -176,8 +177,8 @@ class HighscoreEdit : public QDialog
 
   public:
 
-  int rank;
-  void writeHighscore(int);
+  char rank;
+  void writeHighscore(char);
 
    HighscoreEdit(QWidget* parent, const char* name = 0, WFlags f = 0);
   ~HighscoreEdit(){} };
